@@ -91,23 +91,23 @@ def parse_time(s: str):
     return parse(s)
 
 
-def get_datetime(time_zone: str=None) -> datetime:
+def get_datetime(time_zone: Optional[str]=None) -> datetime:
     return datetime.now() if time_zone is None or len(time_zone) == '' else datetime.now(pytz.timezone(time_zone))
 
 
-def get_datetime_str(time_zone: str=None) -> str:
+def get_datetime_str(time_zone: Optional[str]=None) -> str:
     return datetime.now() if time_zone is None or len(time_zone) == '' else datetime.now(pytz.timezone(time_zone)).strftime(DATETIME_FMT_FULL)
 
 
-def get_date(time_zone: str=None) -> str:
+def get_date(time_zone: Optional[str]=None) -> str:
     return get_datetime(time_zone).strftime(DATETIME_FMT_DATE)
 
 
-def get_datetime_stamp(time_zone: str=None) -> float:
+def get_datetime_stamp(time_zone: Optional[str]=None) -> float:
     return get_datetime(time_zone).timestamp()
 
 
-def get_datetime_from_stamp(timestamp, time_zone: str=None):
+def get_datetime_from_stamp(timestamp, time_zone: Optional[str]=None):
     return datetime.fromtimestamp(timestamp) if time_zone is None else datetime.fromtimestamp(timestamp, pytz.timezone(time_zone))
 
 
@@ -178,7 +178,7 @@ def convert_stamp(stamp: int, original_tz: Union[str, tzinfo], target_tz: Union[
 
     return convert_time_by_timezone(get_datetime_from_stamp(stamp), original_tz, target_tz)
 
-def convert_time(time: Union[int, str, datetime], original_tz: Union[str, tzinfo], target_tz: Union[str, tzinfo]) -> datetime:
+def convert_time(time: Union[int, str, datetime], original_tz: Union[str, tzinfo, None], target_tz: Union[str, tzinfo, None]) -> datetime:
     if isinstance(time, str):
         time = parse_time(time)
     elif isinstance(time, int):
